@@ -2,7 +2,7 @@
 
 import pytest
 
-@pytest.fixture(scope="module")
+@pytest.fixture(scope='package')
 def clumods():
     """ Import all CLU modules that use the “clu.exporting.Exporter”
         mechanism for listing and exporting their module contents
@@ -13,12 +13,13 @@ def clumods():
     
     for modname in MODNAMES:
         module = importlib.import_module(modname)
+        # Only include modules with an instance of “clu.exporting.Exporter”:
         if type(getattr(module, 'exporter', None)).__name__ == 'Exporter':
             modules[modname] = module
     
     yield modules
 
-@pytest.fixture(scope="package")
+@pytest.fixture(scope='package')
 def greektext():
     """ Greek-text fixture: yield a dictionary with several lorem-ipsum-ish
         blocks of text.
@@ -36,7 +37,7 @@ def greektext():
     from clu.constants.data import GREEKOUT
     yield dict(GREEKOUT)
 
-@pytest.fixture(scope="package")
+@pytest.fixture(scope='package')
 def dirname(request):
     """ Fixture for wrapping up the “request.fspath.dirname” value in a
         clu.fs.filesystem.Directory instance – this is intended to be a
@@ -48,7 +49,7 @@ def dirname(request):
     from clu.predicates import resolve
     
     # Get the test-local (née “shared”) data path:
-    dirname = Directory(pth=resolve(request, 'fspath.dirname'))
+    dirname = Directory(resolve(request, 'fspath.dirname'))
     
     # Ensure it exists:
     assert dirname.exists
@@ -71,7 +72,7 @@ def datadir(dirname):
         operations through instance methods (vs. raw calls to “shutil.copytree(…)”).
     """
     from clu.fs.filesystem import TemporaryDirectory
-    from clu.naming import determine_module, dotpath_join, dotpath_to_prefix
+    from clu.naming import moduleof, dotpath_join, dotpath_to_prefix
     
     # Get the test-local (née “shared”) data path:
     datadir = dirname.subdirectory('data')
@@ -81,7 +82,7 @@ def datadir(dirname):
     
     prefix = dotpath_to_prefix(
              dotpath_join(
-             determine_module(TemporaryDirectory), 'ttd', 'datadir'))
+             moduleof(TemporaryDirectory), 'ttd', 'datadir'))
     
     with TemporaryDirectory(prefix=prefix,
                             change=False) as temporarydir:
@@ -113,27 +114,72 @@ def temporarydir():
     
     with TemporaryDirectory(prefix=prefix,
                             change=False) as temporarydir:
+        # Assert that we exist:
+        assert temporarydir.exists
+        
+        # Yield the temporary directory:
         yield temporarydir
     
+    # Assert that we no longer exist after scope exit:
     assert not temporarydir.exists
 
+@pytest.fixture(scope='module')
+def temporaryname():
+    """ clu.fs.filesystem.TemporaryName fixture-factory function: yields
+        a function returning new instances of `TemporaryName`, which
+        can be called multiple times – each time producing a new
+        `TemporaryName` instance under automatic context-management
+        (via a behind-the-scenes “contextlib.ExitStack” instance).
+        
+        The parent fixture is module-scoped; when the module in which
+        this fixture-factory function was first invoked enters cleanup,
+        the ExitStack is unwound and all `TemporaryName` instances are
+        __exit__(…)-ed at that time.
+    """
+    from clu.fs.filesystem import TemporaryName
+    from clu.naming import qualified_name, dotpath_to_prefix
+    from contextlib import ExitStack
+    
+    prefix = dotpath_to_prefix(
+             qualified_name(TemporaryName))
+    
+    # Enter a master-context stack:
+    with ExitStack() as names:
+        
+        # Declare the fixture-factory function:
+        def temporaryname_factory(suffix, prefix=prefix,
+                                          parent=None):
+            """ The TemporaryName clu.testing fixture-factory function """
+            # Enter the new TemoraryName instances’ context,
+            # and return that instance:
+            return names.enter_context(TemporaryName(prefix=prefix,
+                                                     suffix=suffix,
+                                                     parent=parent,
+                                                 randomized=True))
+        
+        # Yield the TemporaryName fixture-factory function:
+        yield temporaryname_factory
+
 @pytest.fixture
 def environment():
     """ Environment testing fixture: yields an instance of `os.environ`,
         free of XDG variables
+        
+        Q.v. implementation https://git.io/JeYmf supra.
     """
     from clu.constants.data import XDGS
     import os
-    stash = {}
+    
+    # Setup: stash environment mapping:
+    stash = os.environ.copy()
     
     # Setup: remove XDG variables from environment:
     for key in XDGS:
         if key in os.environ:
-            stash[key] = os.environ.get(key)
             del os.environ[key]
     
+    # Yield the mapping:
     yield os.environ
     
-    # Teardown: restore environment:
-    for key, value in stash.items():
-        os.environ[key] = value
+    # Teardown: restore environment mapping wholesale:
+    os.environ = stash
